@@ -20,8 +20,8 @@ batch = dict(environ)
 batch["VISUAL"] = "/bin/true"
 
 
-def do_apply(change):
-    run(["pijul", "apply", change], check=True)
+def do_apply(changes):
+    run(["pijul", "apply"] + changes, check=True, stdout=DEVNULL)
 
 
 def new(name):
@@ -433,12 +433,17 @@ def apply(channel):
     """Apply all changes from CHANNEL iteratively"""
     left_set, right_set = fill_channel_sets([channel], [])
     result = left_set - right_set
-    while left_set:
-        change = left_set.pop()
-        print(f"applying {change}")
-        do_apply(change)
-        left_set, right_set = fill_channel_sets([channel], [])
-        result = left_set - right_set
+    total = len(result)
+    with tqdm(total=total) as pbar:
+        while left_set:
+            changes = list(left_set)[:50]
+            do_apply(changes)
+            left_set, right_set = fill_channel_sets([channel], [])
+            result = left_set - right_set
+            l = len(result)
+            done = total - l
+            total = l
+            pbar.update(done)
 
 
 @main.command()
